# Candango Cartola

Candango's Shared Utilities.

Cartola means Top Hat. You see? A magic gets a rabbit from a Top Hat, right?
Right? I think you got the joke...

Right? I'm pretty creative. ;)

We needed a namespace to share some util modules, that's a great one.

## License

**Apache License V2.0**

Copyright © 2015-2020 Flavio Garcia
